# cz-jira-emoji

> Commitizen adapter formatting commit messages using emojis.

**cz-jira-emoji** allows you to easily use emojis in your commits using [commitizen].

```sh
? Select the type of change you are committing: (Use arrow keys)
❯ feature   🚀  A new feature
  fix       🐞  A bug fix
  docs      📚  Documentation change
  refactor  🎨  A code refactoring change
  chore     🔩  A chore change
```

## Install

```bash
npm install --global cz-jira-emoji

# set as default adapter for your projects
echo '{ "path": "cz-jira-emoji" }' > ~/.czrc
```

## Usage

```sh
$ git cz
```

## Customize

By default `cz-jira-emoji` comes preconfigured with the [Gitmoji](https://gitmoji.carloscuesta.me/) types.

But you can customize things on a project basis by adding a configuration section in your `package.json`:

```json
{
  "config": {
    "cz-jira-emoji": {}
  }
}
```

### Types

An [Inquirer.js] choices array:

```json
{
  "config": {
    "cz-jira-emoji": {
      "types": [
        {
          "emoji": "🚀",
          "code": ":rocket:",
          "description": "A new feature",
          "name": "feature"
        }
      ]
    }
  }
}
```

The value `property` must be the emoji itself.

### Config

For anything other than types cz-jira-emoji uses .workflowrc config files.

You should have one of these in the global scope at ~/.workflowrc.

This should contain your Jira login and gitlab token:

```json
{
  "jira": {
    "basic_auth": {
      "base64": "DKFg7ewy578ejshdFG985==",
      "username": "jiraUserName"
    }
  },
  "gitlab": {
    "token": "UCaokvssu7PNny-g-PsS"
  }
}
```

You should also have a .workflowrc config file in the root of your repository which shoud look like this:

```json
{
  "jira": {
    "host": "jira.customJiraURL.com"
  },
  "gitlab": {
    "url": "https://git.custom.gitlaburl.plc",
    "projectNamespace": "namespace",
    "projectName": "projectName",
    "mainBranch": "master"
  },
  "reviewTransitionValue": "131",
  "default-jira-name": "OREO",
  "scopes": ["UI", "api-client", "types"],
  "versioning": ["patch", "minor", "major"]
}
```

## License

MIT © [Mark Lyck](http://markdid.it)

[commitizen]: https://github.com/commitizen/cz-cli
[inquirer.js]: https://github.com/SBoudrias/Inquirer.js/
